@@ -15,13 +15,13 @@
 #
 from typing import (
     Any,
-    AsyncIterable,
+    AsyncIterator,
     Awaitable,
     Callable,
-    Iterable,
     Sequence,
     Tuple,
     Optional,
+    Iterator,
 )
 
 from google.cloud.monitoring_dashboard_v1.types import dashboard
@@ -75,14 +75,14 @@ class ListDashboardsPager:
         return getattr(self._response, name)
 
     @property
-    def pages(self) -> Iterable[dashboards_service.ListDashboardsResponse]:
+    def pages(self) -> Iterator[dashboards_service.ListDashboardsResponse]:
         yield self._response
         while self._response.next_page_token:
             self._request.page_token = self._response.next_page_token
             self._response = self._method(self._request, metadata=self._metadata)
             yield self._response
 
-    def __iter__(self) -> Iterable[dashboard.Dashboard]:
+    def __iter__(self) -> Iterator[dashboard.Dashboard]:
         for page in self.pages:
             yield from page.dashboards
 
@@ -137,14 +137,14 @@ class ListDashboardsAsyncPager:
         return getattr(self._response, name)
 
     @property
-    async def pages(self) -> AsyncIterable[dashboards_service.ListDashboardsResponse]:
+    async def pages(self) -> AsyncIterator[dashboards_service.ListDashboardsResponse]:
         yield self._response
         while self._response.next_page_token:
             self._request.page_token = self._response.next_page_token
             self._response = await self._method(self._request, metadata=self._metadata)
             yield self._response
 
-    def __aiter__(self) -> AsyncIterable[dashboard.Dashboard]:
+    def __aiter__(self) -> AsyncIterator[dashboard.Dashboard]:
         async def async_generator():
             async for page in self.pages:
                 for response in page.dashboards:
