@@ -398,5 +398,8 @@ class DashboardsServiceGrpcAsyncIOTransport(DashboardsServiceTransport):
             )
         return self._stubs["update_dashboard"]
 
+    def close(self):
+        return self.grpc_channel.close()
+
 
 __all__ = ("DashboardsServiceGrpcAsyncIOTransport",)
